'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Boom = require('@hapi/boom');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Boom__default = /*#__PURE__*/_interopDefaultLegacy(Boom);

function errorHandler(server) {
  server.ext('onPreResponse', (request, h) => {
    const res = request.response;
    if (!Boom__default["default"].isBoom(res)) {
      return h.continue;
    }
    const message = res.message || res.output.payload.message;
    const {statusCode} = res.output.payload;
    let code;
    if (res.data && res.data.code != null) {
      code = res.data.code;
    } else {
      if (statusCode >= 400 && statusCode < 500) {
        code = statusCode === 404 ? 3 : 1;
      } else {
        code = 0;
      }
    }
    if (process.env.DEBUG || statusCode >= 500) {
      const {req} = request.raw;
      const debug = {
        method: req.method,
        url: request.url,
        headers: req.headers,
        info: request.info,
        payload: request.payload,
        response: res.output.payload
      };
      server.logger.error(debug);
      server.logger.error(res);
    }
    const response = h.response({
      Message: message,
      Code: code,
      Type: 'error'
    }).code(statusCode);
    const headers = res.output.headers || {};
    Object.keys(headers).forEach(header => {
      response.header(header, `${ headers[header] }`);
    });
    return response;
  });
}

exports.errorHandler = errorHandler;
